==> jc-1.4.0.tar.gz: soot/jimple/spark/fieldrw/FieldRWTag.h <==
// public abstract class soot.jimple.spark.fieldrw.FieldRWTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 26c009a8a59d47e0 soot_jimple_spark_fieldrw_FieldRWTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldRWTag_H_
#define _JC_soot_jimple_spark_fieldrw_FieldRWTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$refs	_jc_soot_jimple_spark_fieldrw_FieldRWTag$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldRWTag$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object	_jc_soot_jimple_spark_fieldrw_FieldRWTag$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtable	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldRWTag$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *);
extern _jc_byte_array *_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldRWTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldRWTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldRWTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *);
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods	soot_jimple_spark_fieldrw_FieldRWTag;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs {
	struct _jc_java_lang_String$object	*fieldNames;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$refs {
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldRWTag;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object {
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype _jc_soot_jimple_spark_fieldrw_FieldRWTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldRWTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldRWTag$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldRWTag_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/fieldrw/FieldRWTag.h <==
// public abstract class soot.jimple.spark.fieldrw.FieldRWTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 26c009a8a59d47e0 soot_jimple_spark_fieldrw_FieldRWTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldRWTag_H_
#define _JC_soot_jimple_spark_fieldrw_FieldRWTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$refs	_jc_soot_jimple_spark_fieldrw_FieldRWTag$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldRWTag$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object	_jc_soot_jimple_spark_fieldrw_FieldRWTag$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtable	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldRWTag$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldRWTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldRWTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldRWTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldRWTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods	soot_jimple_spark_fieldrw_FieldRWTag;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs {
	struct _jc_java_lang_String$object	*fieldNames;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$refs {
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldRWTag;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldRWTag$object {
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldRWTag$vtype _jc_soot_jimple_spark_fieldrw_FieldRWTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldRWTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldRWTag$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldRWTag_H_ */
